summaryrefslogtreecommitdiff
path: root/invest-applet/invest/invest-applet.py
diff options
context:
space:
mode:
Diffstat (limited to 'invest-applet/invest/invest-applet.py')
-rwxr-xr-xinvest-applet/invest/invest-applet.py28
1 files changed, 14 insertions, 14 deletions
diff --git a/invest-applet/invest/invest-applet.py b/invest-applet/invest/invest-applet.py
index 884bcba8..1e08c5ab 100755
--- a/invest-applet/invest/invest-applet.py
+++ b/invest-applet/invest/invest-applet.py
@@ -19,20 +19,20 @@ else:
sys.path.insert(0, abspath("@PYTHONDIR@"))
# Now the path is set, import our applet
-import invest, invest.applet, invest.defs, invest.help
+import mate_invest, mate_invest.applet, mate_invest.defs, mate_invest.help
# Prepare i18n
import gettext, locale
-gettext.bindtextdomain(invest.defs.GETTEXT_PACKAGE, invest.defs.MATELOCALEDIR)
-gettext.textdomain(invest.defs.GETTEXT_PACKAGE)
-locale.bindtextdomain(invest.defs.GETTEXT_PACKAGE, invest.defs.MATELOCALEDIR)
-locale.textdomain(invest.defs.GETTEXT_PACKAGE)
+gettext.bindtextdomain(mate_invest.defs.GETTEXT_PACKAGE, mate_invest.defs.MATELOCALEDIR)
+gettext.textdomain(mate_invest.defs.GETTEXT_PACKAGE)
+locale.bindtextdomain(mate_invest.defs.GETTEXT_PACKAGE, mate_invest.defs.MATELOCALEDIR)
+locale.textdomain(mate_invest.defs.GETTEXT_PACKAGE)
from gettext import gettext as _
def applet_factory(applet, iid):
- invest.debug('Starting invest instance: %s %s'% ( applet, iid ))
- invest.applet.InvestApplet(applet)
+ mate_invest.debug('Starting invest instance: %s %s'% ( applet, iid ))
+ mate_invest.applet.InvestApplet(applet)
return True
# Return a standalone window that holds the applet
@@ -77,12 +77,12 @@ if __name__ == "__main__":
if o in ("-h", "--help"):
usage()
elif o in ("-d", "--debug"):
- invest.DEBUGGING = True
- invest.debug("Debugging enabled")
- # these messages cannot be turned by invest.DEBUGGING at their originating location,
+ mate_invest.DEBUGGING = True
+ mate_invest.debug("Debugging enabled")
+ # these messages cannot be turned by mate_invest.DEBUGGING at their originating location,
# because that variable was set here to be True
- invest.debug("Data Dir: %s" % invest.SHARED_DATA_DIR)
- invest.debug("Detected PROXY: %s" % invest.PROXY)
+ mate_invest.debug("Data Dir: %s" % mate_invest.SHARED_DATA_DIR)
+ mate_invest.debug("Detected PROXY: %s" % mate_invest.PROXY)
elif o in ("-w", "--window"):
standalone = True
@@ -93,6 +93,6 @@ if __name__ == "__main__":
mateapplet.matecomponent_factory(
"OAFIID:Invest_Applet_Factory",
mateapplet.Applet.__gtype__,
- invest.defs.PACKAGE,
- invest.defs.VERSION,
+ mate_invest.defs.PACKAGE,
+ mate_invest.defs.VERSION,
applet_factory)